/*************************************************  Channel Functions Header  **************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	Copyright 2014, Red Rapids, Inc.

*************************************************  Channel Functions Header  **************************************************/

#ifndef _CHANNEL_FUNCTIONS_H_
#define _CHANNEL_FUNCTIONS_H_

#if defined(__cplusplus)
	extern "C" {
#endif

// Structure to store the IF data source select configuration settings.
typedef struct
{
	unsigned long long ChannelSelect;
	unsigned long long Amplitude;
} s_SwitchSelect;

// Structure to store the IF data payload configuration settings.
typedef struct
{
	unsigned long long PayloadPacking;
	unsigned long long Endianness;
	unsigned long long DataItemSize;
	unsigned long long EventTagOrder;
	unsigned long long EventTagMask;
	unsigned long long EventTagIndex;
	unsigned long long ItemPackingFieldSize;
	unsigned long long ChannelTag;
} s_PayloadFormat;

// Structure to store the datapath control configuration settings.
typedef struct
{
	unsigned long long Transform[6];
	unsigned long long Residue[2];
	unsigned long long SyncInitMask[4];
	unsigned long long SyncCycleMask[4];
} s_DatapathControl;

// Structure to store the synchronizer configuration settings.
typedef struct
{
	unsigned long long StartEvent;
	unsigned long long StartOffset;
	unsigned long long StopEvent;
	unsigned long long StopOffset;
	unsigned long long CycleSelect;
	unsigned long long CycleStop;
} s_Synchronizer;

// Structure to store the TOD trigger configuration settings.
typedef struct
{
	unsigned long long IntegerSecondsStart;
	unsigned long long FractionalSecondsStart;
	unsigned long long IntegerSecondsStop;
	unsigned long long FractionalSecondsStop;
} s_TODTriggers;

// Structure to store the event duration configuration settings.
typedef struct
{
	unsigned long long SampleCount;
	unsigned long long BurstCount;
	unsigned long long CycleCount;
	unsigned long long FrameCount;
} s_EventDuration;

// Structure to store IF data packet configuration settings.
typedef struct
{
	unsigned long long PacketSize;
	unsigned long long TSFSelect;
	unsigned long long TSISelect;
	unsigned long long TrailerSelect;
	unsigned long long ClassIDSelect;
	unsigned long long ClassID;
	unsigned long long StreamIDSelect;
	unsigned long long StreamID;
	unsigned long long ContextPktCntEnable;
	unsigned long long IndicatorEnables;
	unsigned long long SpectralInversion;
	unsigned long long UserIndicators[3];
} s_IFdpktFormat;

// Structure to reference all of the configuration settings for a channel.
typedef struct
{
	s_SwitchSelect SwitchSelect;
	s_PayloadFormat PayloadFormat;
	s_DatapathControl DatapathControl;
	s_Synchronizer Synchronizer;
	s_TODTriggers TODTriggers;
	s_EventDuration EventDuration;
	s_IFdpktFormat IFdpktFormat;
	s_DMABuffer DMABuffer;
} s_Channel;

// Structure to store the results returned by a channel status query to the device.
typedef struct
{
	unsigned long DMAMarker;
	unsigned long Error[2];
} s_ChannelStatus;

// Structure to store interrupt mask settings assigned to each type of channel event.
typedef struct
{
	unsigned long DMAMarker;
	unsigned long Error[2];
} s_ChannelIntMask;

// Prototypes for each of the channel functions.
unsigned long ChannelMask(s_Adapter *p_HW, unsigned long ChannelNumber, s_ChannelIntMask ChannelIntMask);
unsigned long ChannelReset(s_Adapter *p_HW, unsigned long ChannelNumber);
unsigned long ClearChannelStatus(s_Adapter *p_HW, unsigned long ChannelNumber);
unsigned long FlowControl(s_Adapter *p_HW, unsigned long ChannelNumber, unsigned long OnOff);
unsigned long FlowStatus(s_Adapter *p_HW, unsigned long ChannelNumber);
unsigned long GetChannelStatus(s_Adapter *p_HW, unsigned long ChannelNumber, s_ChannelStatus *p_ChannelStatus);
unsigned long LoadChannel(s_Adapter *p_HW, unsigned long ChannelNumber, s_Channel Channel);
unsigned long LoadDatapathControl(s_Adapter *p_HW, unsigned long ChannelNumber, s_DatapathControl DatapathControl);
unsigned long LoadEventDuration(s_Adapter *p_HW, unsigned long ChannelNumber, s_EventDuration EventDuration);
unsigned long LoadIFdpktFormat(s_Adapter *p_HW, unsigned long ChannelNumber, s_IFdpktFormat IFdpktFormat);
unsigned long LoadPayloadFormat(s_Adapter *p_HW, unsigned long ChannelNumber, s_PayloadFormat PayloadFormat);
unsigned long LoadSwitchSelect(s_Adapter *p_HW, unsigned long ChannelNumber, s_SwitchSelect SwitchSelect);
unsigned long LoadSynchronizer(s_Adapter *p_HW, unsigned long ChannelNumber, s_Synchronizer Synchronizer);
unsigned long LoadTODTriggers(s_Adapter *p_HW, unsigned long ChannelNumber, s_TODTriggers TODTriggers);
unsigned long ReadyStatus(s_Adapter *p_HW, unsigned long ChannelNumber);

#ifdef __cplusplus
}
#endif

#endif
