/**************************************************  Signal Stream Header  ***************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	Rev History: 10-16-2012:	Added support for programmable synthesizer, PCI performance monitor, and interrupt timer.
	Rev History: 5-1-2012:		Inital release.

	Copyright 2012, Red Rapids, Inc.

**************************************************  Signal Stream Header  ***************************************************/

#ifndef _SIGNAL_STREAM_H_
#define _SIGNAL_STREAM_H_

#if defined(__cplusplus)
	extern "C" {
#endif

// The following user defined structure is used to pass information between the main application and the interrupt service routine (ISR).
// Note: It can be modified to suit a specific application. 
typedef struct
{
	unsigned long RXChannelCount;
	unsigned long RXDataItemSize;
	unsigned long TXChannelCount;
	unsigned long TXDataItemSize;
	unsigned long MarkerIndex[4];
	unsigned long MaxMarkerIndex[4];
	void *p_DataBuffer[4][1024];
	unsigned long Error[4][3];
} s_User;

// Define the directory separator character for Windows and Linux.
#ifdef WIN32
#define SEPARATOR "\\"
#else
#define SEPARATOR "/"
#endif

// The following constants are assigned to all Signal Stream hardware.

// Device numbers:
#define DEV0 0
#define DEV1 1
#define DEV2 2
#define DEV3 3
#define DEV4 4
#define DEV5 5
#define DEV6 6
#define DEV7 7

// BAR numbers:
#define BAR0 0
#define BAR2 2

// BAR0 register names:
#define SOFTWARE_RESET 0x0000
#define CLOCK_INITIALIZE 0x0008
#define ERROR_STATUS 0x0010
#define ERROR_INT_MASK 0x0018
#define GLOBAL_STATUS 0x0100
#define GLOBAL_INT_MASK 0x0108
#define INTERRUPT_LATENCY 0x0110
#define INTERRUPT_TIMEOUT 0x0118
#define SERIAL_PAYLOAD 0x0020
#define SERIAL_CONFIG 0x0030
#define SERIAL_COMMAND 0x0038
#define PCI_THROUGHPUT 0x0050
#define PCI_LATENCY 0x0058
#define DMA_1TO2_STATUS 0x1F00
#define DMA_3TO4_STATUS 0x1F08
#define DMA_5TO6_STATUS 0x1F10
#define DMA_7TO8_STATUS 0x1F18
#define DMA_DESCRIPTORS 0x2000

// BAR2 register names for functions that are common to all channels:
#define IDENTIFICATION 0x0000
#define TOD_SETTINGS 0x0020
#define TSI_TSF_CODE 0x0028
#define SOFTWARE_TRIGGER 0x0030
#define GLOBAL_SYNC 0x0038
#define LED_SOURCE_MASK 0x0040
#define GPIO_SETTINGS 0x0048

// BAR2 register names for functions that are unique to each channel.
// Note: This is the register base address from a predefined offset for each channel.
#define SYNCHRONIZER_CTL 0x0000
#define CHANNEL_RESET 0x0008
#define CHANNEL_STATUS 0x0010
#define CHANNEL_INT_MASK 0x0018
#define SWITCH_SELECT 0x0030
#define PAYLOAD_FORMAT 0x0040
#define DATAPATH_CONTROL 0x0050
#define DATAPATH_MONITOR 0x0058
#define SYNCHRONIZER_CMD 0x0060
#define CHANNEL_STATE 0x0068
#define TOD_TRIGGERS1 0x0070
#define TOD_TRIGGERS2 0x0078
#define EVENT_DURATION1 0x0080
#define EVENT_DURATION2 0x0088
#define IF_DPKT_FORMAT1 0x0100
#define IF_DPKT_FORMAT2 0x0108
#define IF_DPKT_FORMAT3 0x0110
#define TUNER_CONTROL 0x0200
#define FILTER_CONTROL 0x0208
#define FILTER_CONFIG_DATA 0x0210
#define FILTER_CONFIG_CMD 0x0218
#define FILTER_CONFIG_STAT 0x0218

// Serial bus transaction types:
#define I2C_READ 1
#define I2C_WRITE 0
#define RISING_EDGE 1
#define FALLING_EDGE 0
// Serial bus type select:
// 0 => I2C
// 1 => SPI unidirectional bus (SDI/SDO)
// 2 => SPI chip select port expander (serial shift register)
// 3 => SPI bidirectional bus (SDIO)
// 4 => GPIO/user translator port expander (serial shift register)
// 3 => Programmable synthesizer
#define I2C 0
#define SPI 1
#define MICROWIRE 1
#define SPI_CSB 2
#define SPI_SDIO 3
#define GPIO_USER_DIRECTION 4
#define SYNTH 5
// Payload format by device (instruction size and data size):
#define AD9142A_INST 16
#define AD9142A_DATA 8
#define AD9512_INST 16
#define AD9512_DATA 8
#define AD9652_INST 16
#define AD9652_DATA 8
#define ADC12D1600_INST 8
#define ADC12D1600_DATA 16
#define ADS42LB69_INST 8
#define ADS42LB69_DATA 8
#define FXL6408_DATA 8
#define INA3221_DATA 16
#define LMK01000_ADD 4
#define LMK01000_DATA 28
#define LTC1661_INST 4
#define LTC1661_DATA 12
#define LTC2991_DATA 8
// Serial bus chip selects by product:
#define ALL_DESELECT 0xFFFF
#define CMD_STAT1 0x86
#define DEFAULT_CLK_DIST 0xFFFE
#define M271_CLK_DIST 0xFFFE
#define M271_RX1TO2_ADC 0xFFFD
#define M271_RX1_TRIM_DAC 0xFFF7
#define M271_RX2_TRIM_DAC 0xFFEF
#define M273_CLK_DIST 0xFFFE
#define M273_RX1TO2_ADC 0xFFFD
#define M273_RX2_TRIM_DAC 0xFFF7
#define M273_RX1_TRIM_DAC 0xFFEF
#define M273_CLK_DIST_SYNC 0xFF7F
#define M276_RX1TO2_ADC 0xFFFE
#define M276_RX1_TRIM_DAC 0xFFFD
#define M276_RX2_TRIM_DAC 0xFFFB
#define M277_CLK_DIST 0xFFFE
#define M277_RX1TO2_ADC 0xFFFD
#define M277_RX3TO4_ADC 0xFFFB
#define M277_RX1_TRIM_DAC 0xFFF7
#define M277_RX2_TRIM_DAC 0xFFEF
#define M277_RX3_TRIM_DAC 0xFFDF
#define M277_RX4_TRIM_DAC 0xFFBF
#define TEMP_MONITOR 0x92
#define VOLT_MONITOR 0x80

#ifdef __cplusplus
}
#endif

#endif
